@@ -20,7 +20,7 @@ impl From<Number> for f64 {
 
 impl From<Number> for usize {
     fn from(number: Number) -> Self {
-        number.value as usize
+        number.value as Self
     }
 }
 
@@ -30,4 +30,4 @@ impl From<f64> for Number {
     }
 }
 
-type_information!(byte_string, crate::number::Number);
+type_information!(number, crate::number::Number);
